Kategorie
=========

Stamdaten
---------

Name
   Der Name der Kategorie. Dieser wird u.a. in der Navigation angezeigt.

Slug 
   Dies ist Teil der URL um die Kategorie anzuzeigen. Dieser muss einzigartig 
   unter allen Kategorien sein.
   
Elternkategorie
   Die direkt übergeordnete Kategorie. Falls diese leer ist, handelt es sich 
   um eine :term:`Top-Level-Kategorie` des Shops.

Kurzbeschreibung
   Kurze Beschreibung der Kategorie. Diese wird in einer Übersicht über 
   Kategorien angezeigt, beispielsweise wenn die Ansichtsart ``Unterkategorien``
   für eine Kategorie oder den Shop ausgewählt ist.
   
Beschreibung
   Die Beschreibung der Kategorie. Diese wird in der Detailansicht einer 
   Kategorie angezeigt.

Bild
   Das Bild der Kategorie. Diese wird in einer Kategorienübersicht angezeigt, 
   beispielsweise wenn für den ``Inhalt`` ``Unterkategorien`` ausgewählt ist.

Statischer Block
   Ein HTML Block, der abhängig vom verwendeten Design in verschiedenen Bereichen
   der Kategorie angezeigt werden kann, z.B. im Kopf.
   
Inhalt
   Hier wird ausgewählt, ob Produkte oder Unterkatorien für diese Kategorie 
   angezeigt wird.

Formate aktivieren
   Falls ausgewählt, werden ``Produktzeilen``, ``Produktspalten`` und 
   ``Kategoriespalten`` dieser Kategorie aktiviert. Andernfalls erbt die 
   Kategorie Formate von der Übergeordneten Kategorie bzw. die Standardformate
   des Shops.
   
Produktzeilen
   Falls die Kategorie Produkte anzeigt, ist das die Anzahl der Zeilen, die 
   angezeigt werden. Diese Angabe wird nur beachtet, wenn `Formate aktiveren`
   ausgewählt ist.

Produktspalten
   Falls die Kategorie Produkte anzeigt, ist das die Anzahl der Spalten, die 
   angezeigt werden. Diese Angabe wird nur beachtet, wenn `Formate aktiveren`
   ausgewählt ist.
   
Kategoriespalten
   Falls die Kategorie Unterkategorien anzeigt, ist das die Anzahl der Spalten, 
   die angezeigt werden. Es werden immer alle Unterkategorien angezeigt, so dass
   die Anzahl der Zeilen für Kategorien entfällt. Diese Angabe wird nur beachtet, 
   wenn ``Formate aktiveren`` ausgewählt ist.

Produkte
--------

Hier werden der Kategorie Produkte zugewiesen. 

Die obere Tabelle enthält alle Produkte des Shops, die dieser Kategorie noch 
nicht zugewiesen worden sind.

Die untere Tabelle enthält alle Produkte, die dieser Kategorie zugewiesen sind.

SEO
---

Hier können Daten zur Suchmaschinenoptimierung eingetragen werden.

Meta keywords
   Die :term:`Meta keywords` der Kategorie. Sie können das LFS spezifische Tag
   ``<name>`` verwenden um den Namen der Kategorie zu übernehmen.
   
Meta description
   Die :term:`Meta description` der Kategorie. Sie können das LFS spezifische 
   Tag ``<description>`` verwenden um den Namen der Kategorie zu übernehmen. 
